Downloading and Loading
----------------------------------------------------

These include methods for downloading DaCy models and loading them into memory.


dacy.download
~~~~~~~~~~~~~~~~~~~~~

.. automodule:: dacy.download
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: DownloadProgressBar, download_url


dacy.load
~~~~~~~~~~~~~~~~~~~~~

.. automodule:: dacy.load
   :members:
   :undoc-members:
   :show-inheritance:

